@@ -1,7 +1,7 @@
 use crate::Args;
 
-use std::process;
 use std::fs;
+use std::process;
 
 pub fn dog(args: Args) {
     if args.debug {
@@ -34,18 +34,19 @@ pub fn dog(args: Args) {
             ln += 1;
 
             // Handle numbered line cases
-            if (args.number_nonblank && token.len() != 0 ) || (!args.number_nonblank && args.number) {
+            if (args.number_nonblank && token.len() != 0) || (!args.number_nonblank && args.number)
+            {
                 print!("|{ln}| ");
             }
-                
+
             print!("{token}");
 
             // Handle the $ end case
             if args.show_ends {
                 print!("$");
             }
-            
+
             println!();
         }
     }
-}
\ No newline at end of file
+}
