@@ -9,7 +9,7 @@ pub struct Args {
     #[clap(short, long)]
     debug: bool,
 
-    /// Number all nonempty output lines, starting with 1. 
+    /// Number all nonempty output lines, starting with 1.
     #[clap(short = 'b', long)]
     number_nonblank: bool,
 
@@ -22,10 +22,10 @@ pub struct Args {
     number: bool,
 
     /// Prints each file to stdout.
-    inputs: Vec<String>
+    inputs: Vec<String>,
 }
 
 fn main() {
     let args: Args = Args::parse();
     dog::dog(args);
-}
\ No newline at end of file
+}
